### Name: Matlab
### Title: Matlab client for remote or local Matlab access
### Aliases: Matlab
### Keywords: classes

### ** Examples
## Not run: # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
##D # This example will try to start the Matlab server on the local machine,
##D # and then setup a Matlab object in R for communicating data between R
##D # and Matlab and for sending commands from R to Matlab.
##D # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
##D 
##D # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
##D # 1.  Load R.matlab
##D # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
##D library(R.matlab)
##D 
##D # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
##D # 2.  Start Matlab
##D # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
##D # 2.1.  Start Matlab from R?
##D # Start Matlab server on the local machine (if this fails,
##D # see help(Matlab) for alternatives).
##D Matlab$startServer()
##D 
##D # 2.2.  OR start Matlab externally,
##D #       THEN add 'externals' subdirectory to the Matlab path
##D 
##D #  (Where is the 'externals' subdirectory?)
##D print(system.file("externals", package="R.matlab"))
##D 
##D #       THEN from within Matlab,
##D #            issue Matlab command "MatlabServer"
##D # Note: If issued from a Matlab command line, this last command
##D #       prevents further Matlab 'command line' input
##D #       until something like close(matlab) at the end of this script
##D 
##D # 2.3.  If both these options fail, see help(Matlab) for alternatives.
##D 
##D # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
##D # 3. Create a Matlab client object used to communicate with Matlab
##D # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
##D matlab <- Matlab()
##D 
##D # 3.1 If you experience any problems, ask for detailed outputs
##D #     by uncommenting the next line
##D # setVerbose(matlab, -2)
##D 
##D # 3.2   Connect to the Matlab server.
##D isOpen <- open(matlab)
##D 
##D # 3.3.  Confirm that the Matlab server is open, and running
##D if (!isOpen)
##D   throw("Matlab server is not running: waited 30 seconds.")
##D 
##D # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
##D # 4.  Sample uses of the Matlab server
##D # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
##D # 4.1 Run Matlab expressions on the Matlab server
##D evaluate(matlab, "A=1+2;", "B=ones(2,20);")
##D 
##D # 4.2 Get Matlab variables
##D data <- getVariable(matlab, c("A", "B"))
##D cat("Received variables:\n")
##D str(data)
##D 
##D # 4.3 Set variables in Matlab
##D ABCD <- matrix(rnorm(10000), ncol=100)
##D str(ABCD)
##D setVariable(matlab, ABCD=ABCD)
##D 
##D # 4.4 Retrieve what we just set
##D data <- getVariable(matlab, "ABCD")
##D cat("Received variables:\n")
##D str(data)
##D 
##D # 4.5 Create a function (M-file) on the Matlab server
##D setFunction(matlab, "          \
##D   function [win,aver]=dice(B)  \
##D   %Play the dice game B times  \
##D   gains=[-1,2,-3,4,-5,6];      \
##D   plays=unidrnd(6,B,1);        \
##D   win=sum(gains(plays));       \
##D   aver=win/B;                  \
##D ");
##D 
##D # 4.6 Use the Matlab function just created
##D evaluate(matlab, "[w,a]=dice(1000);")
##D res <- getVariable(matlab, c("w", "a"))
##D print(res)
##D 
##D # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
##D # 5.  Done:  close the Matlab client
##D # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
##D # When done, close the Matlab client, which will also shutdown
##D # the Matlab server and the connection to it.
##D close(matlab)
##D 
## End(Not run)


